#
# spec file for package python-pem
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pem
Version:        23.1.0
Release:        1.4
Summary:        PEM file parsing in Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/hynek/pem
Source0:        https://files.pythonhosted.org/packages/source/p/pem/pem-%{version}.tar.gz
BuildRequires:  %{python_module Twisted-tls}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module hatch-fancy-pypi-readme}
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
pem is a Python module for parsing and splitting of PEM files,
i.e. Base64 encoded DER keys and certificates.

%prep
%setup -q -n pem-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand rm %{buildroot}/%{$python_sitelib}/pem/py.typed #zero length

%check
%pytest tests

%files %{python_files}
%license LICENSE
%doc README.md CHANGELOG.md
%{python_sitelib}/pem
%{python_sitelib}/pem-%{version}.dist-info

%changelog
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 23.1.0:
  * Support for Python 2.7, 3.5, and 3.6 has been dropped.
  * Support for RFC 4880 OpenPGP private & public keys:
    `pem.OpenPGPPublicKey` and `pem.OpenPGPPrivateKey`.
  * Support for intra-payload headers like the ones used in
    OpenPGP keys using the `meta_headers` property.
  * `pem.parse_file()` now accepts also `pathlib.Path` objects.
  * `pem.parse()` now also accepts `str`.
  * Added `text_payload`, `bytes_payload` and `decoded_payload`
    properties to all PEM objects that allow to directly access
    the payload without the envelope and possible headers.
* Mon Jul  3 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jun 21 2022 Ben Greiner <code@bnavigator.de>
- Update to 21.2.0
  * Added support for pem.OpenSSLTrustedCertificate (-----BEGIN
    TRUSTED CERTIFICATE-----), as defined in openssl x509 manual.
    [#28]
  * Added support for DSA private keys (BEGIN DSA PRIVATE). This is
    also the OpenSSH legacy PEM format. #49
  * Added support for pem.SSHPublicKey (---- BEGIN SSH2 PUBLIC KEY
  - ---), as defined in RFC 4716. #46
  * Added support for pem.SSHCOMPrivateKey (---- BEGIN SSH2
    ENCRYPTED PRIVATE KEY ----), the SSH.com / Tectia private key
    format (plain or encrypted). #46
- Actually requires twisted[tls]: python-Twisted-tls
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 20.1.0
  - Carriage returns (``\r``) are now stripped before hashing ``pem`` objects to provide consistent hashes across platforms.
    `#40 <https://github.com/hynek/pem/issues/40>`_
  - Python 3.4 is not supported anymore.
    It has been unsupported by the Python core team for a while now and its PyPI downloads are negligible.
  - Added support for ``pem.OpenSSHPrivateKey`` (``OPENSSH PRIVATE KEY``).
    OpenSSH added a new ``BEGIN`` label when it switched to a proprietary key encoding.
    `#39 <https://github.com/hynek/pem/pull/39>`_
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 19.2.0:
  * Added support for pem.ECPrivateKey (EC PRIVATE KEY).
* Fri May 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 19.1.0
  * You can now load encrypted PKCS#8 PEM key as ``pem.Key``.
  * Added support for ``pem.PublicKey`` (``PUBLIC KEY``).
  * Added support for ``pem.RSAPublicKey`` (``RSA PUBLIC KEY``).
* Tue Feb 12 2019 Jan Engelhardt <jengelh@inai.de>
- Trim replicated metadata from description.
* Tue Feb 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Mark as noarch since the package does not compile anything
* Thu Feb  7 2019 ecsos@opensuse.org
- initial version 18.2.0
